==> Demo_STC12C5A60S2_ST7789V2_3-Line_Hardware_SPI.zip: Demo_STC12C5A60S2_ST7789V2_3-Line_Hardware_SPI/user/main.h <==
/**********************************************************************
 * 本程序只供学习使用，未经作者许可，不得用于其它任何用途
 * 测试硬件：单片机STC12C5A60S2,主频12MHZ
 * 程序说明：ST7789V 3线制硬件SPI程序
 
 ----------------------------------------------------
 |深圳市千一显示科技有限公司                        |
 |公司网站:www.qytft.com                            |
 |淘宝网站：https://shop580133616.taobao.com        |
 |固话(传真) :+86 0755-27908130                     |
 |业务咨询:18823372746 (徐经理 WX同号)              |
 |业务咨询:15989313508 (冯经理 WX同号)              |
 ----------------------------------------------------

 ----------------------------------------------------
 |我司提供技术支持，任何技术问题欢迎随时交流学习    |
 |技术支持QQ:3597321058                             |
 |技术支持邮箱:qyxskj@126.com                       |
 |技术支持:13723763193（周工 WX同号）               |
 |技术交流QQ群:792027219                            |
 ----------------------------------------------------

 * 接线说明:
 ========================电源引脚接线==================================        
 |   LCD模块           单片机引脚                                     |
 |     VCC      --->      5V        //电源                            |
 |     GND      --->      GND       //电源地                          | 
 |====================控制及数据引脚接线==============================|
 |   LCD模块 			     单片机引脚                                     |
 |     CS       --->      P13       //液晶屏片选控制信号（低电平有效）|
 |     RST      --->      P33       //液晶屏复位控制信号（低电平有效）|
 |     SCL      --->      P17       //液晶屏SPI总线时钟信号           |
 |     SDI      --->      P15       //液晶屏SPI总线写数据信号         |
 |     SDO      --->      P16       //液晶屏SPI总线读数据信号         |
 ======================================================================
 
 * 创建日期:2020/5/13
 * 版本：V1.0
 * 版权所有，盗版必究。
 * Copyright(C) 深圳市千一显示科技有限公司 2020-2035
 * All rights reserved
**********************************************************************/
#include <reg51.h>
#include <intrins.h>

#define	u8 unsigned char
#define	u16 unsigned int
#define	u32 unsigned long

//////////////////////////////////////////////////////////////////////////////////	  
//定义LCD的尺寸
#define LCD_W 240
#define LCD_H 320

#define SET_X_ADD_CMD 0x2A
#define SET_Y_ADD_CMD 0x2B
#define WR_RAM_CMD 0x2C

//IO连接
sbit LCD_SDI = P1^5;		  //SPI写
sbit LCD_SDO = P1^6;		     //SPI读
sbit LCD_CS = P1^3;		//片选	
sbit LCD_CLK = P1^7;   //SPI时钟
sbit LCD_RESET = P3^3;	      //复位 
//sbit LCD_BL=P3^2;		//背光控制，如果不需要控制，接3.3V

//测试硬件平台：STC12C5A60S2/STC12LE5A60S2
//主频：12MHZ
//单片机IO推挽输出设置定义
#define MCU_STC12//如果您使用的单片机不是STC12系列(如STC89C52)请屏蔽此宏定义
#define		MAIN_Fosc	12000000L	//定义时钟
#ifdef MCU_STC12
//sfr P3M1  = 0xB1;	//P3M1.n,P3M0.n 	=00--->Standard,	01--->push-pull
//sfr P3M0  = 0xB2;	//					=10--->pure input,	11--->open drain
sfr AUXR1 = 0xA2;
#endif
//-----------------------------SPI 总线配置--------------------------------------//
//STC单片机硬件SPI寄存器定义
sfr SPSTAT = 0xCD;	//STC12C5A60S2系列
sfr SPCTL  = 0xCE;	//STC12C5A60S2系列
sfr SPDAT  = 0xCF;	//STC12C5A60S2系列
//sfr SPCTL   = 0x85;	SPI控制寄存器
//   7       6       5       4       3       2       1       0    	Reset Value
//	SSIG	SPEN	DORD	MSTR	CPOL	CPHA	SPR1	SPR0		0x00
#define	SSIG		1	//1: 忽略SS脚，由MSTR位决定主机还是从机		0: SS脚用于决定主从机。
#define	SPEN		1	//1: 允许SPI，								0：禁止SPI，所有SPI管脚均为普通IO
#define	DORD		0	//1：LSB先发，								0：MSB先发
#define	MSTR		1	//1：设为主机								0：设为从机
#define	CPOL		1	//1: 空闲时SCLK为高电平，					0：空闲时SCLK为低电平
#define	CPHA		1	//
#define	SPR1		0	//SPR1,SPR0   00: fosc/4,     01: fosc/16
#define	SPR0		0	//            10: fosc/64,    11: fosc/128
#define	SPEED_4		0	// fosc/4
#define	SPEED_16	1	// fosc/16
#define	SPEED_64	2	// fosc/64
#define	SPEED_128	3	// fosc/128

//sfr SPSTAT  = 0xCD;	//SPI状态寄存器
//   7       6      5   4   3   2   1   0    	Reset Value
//	SPIF	WCOL	-	-	-	-	-	-
#define	SPIF	0x80		//SPI传输完成标志。写入1清0。
#define	WCOL	0x40		//SPI写冲突标志。写入1清0。

//STC单片机IO推挽输出设置定义
//其他普通C51单片机无此配置请屏蔽下面这条语句

sfr P3M1  = 0xB1;	//P3M1.n,P3M0.n 	=00--->Standard,	01--->push-pull
sfr P3M0  = 0xB2;	//					=10--->pure input,	11--->open drain

//画笔颜色
#define WHITE         	 0xFFFF
#define BLACK         	 0x0000	  
#define BLUE         	 0x001F  
#define BRED             0XF81F
#define GRED 			 0XFFE0
#define GBLUE			 0X07FF
#define RED           	 0xF800
#define MAGENTA       	 0xF81F
#define GREEN         	 0x07E0
#define CYAN          	 0x7FFF
#define YELLOW        	 0xFFE0
#define BROWN 			 0XBC40 //棕色
#define BRRED 			 0XFC07 //棕红色
#define GRAY  			 0X8430 //灰色
#define GRAY0       0xEF7D 
#define GRAY1       0x8410      	//灰色1      00000 000000 00000
#define GRAY2       0x4208 
//GUI颜色

#define DARKBLUE      	 0X01CF	//深蓝色
#define LIGHTBLUE      	 0X7D7C	//浅蓝色  
#define GRAYBLUE       	 0X5458 //灰蓝色
//以上三色为PANEL的颜色 
 
#define LIGHTGREEN     	 0X841F //浅绿色
#define LGRAY 			 0XC618 //浅灰色(PANNEL),窗体背景色

#define LGRAYBLUE        0XA651 //浅灰蓝色(中间层颜色)
#define LBBLUE           0X2B12 //浅棕蓝色(选择条目的反色)

==> Demo_STC12C5A60S2_ST7789V2_4-Line_Hardware_SPI.zip: Demo_STC12C5A60S2_ST7789V2_4-Line_Hardware_SPI/user/main.h <==
/**********************************************************************
 * 本程序只供学习使用，未经作者许可，不得用于其它任何用途
 * 测试硬件：单片机STC12C5A60S2,主频12MHZ
 * 程序说明：ST7789V 4线制硬件SPI程序
 
 ----------------------------------------------------
 |深圳市千一显示科技有限公司                        |
 |公司网站:www.qytft.com                            |
 |淘宝网站：https://shop580133616.taobao.com        |
 |固话(传真) :+86 0755-27908130                     |
 |业务咨询:18823372746 (徐经理 WX同号)              |
 |业务咨询:15989313508 (冯经理 WX同号)              |
 ----------------------------------------------------

 ----------------------------------------------------
 |我司提供技术支持，任何技术问题欢迎随时交流学习    |
 |技术支持QQ:3597321058                             |
 |技术支持邮箱:qyxskj@126.com                       |
 |技术支持:13723763193（周工 WX同号）               |
 |技术交流QQ群:792027219                            |
 ----------------------------------------------------

 * 接线说明:
 ========================电源引脚接线=======================================================        
 |   LCD模块           单片机引脚                                                          |
 |     VCC      --->      3.3V      //电源                                                 |
 |     GND      --->      GND       //电源地                                               |  
 |====================控制及数据引脚接线===================================================|
 |   LCD模块  			   单片机引脚                                                          |
 |     CS       --->      P13       //液晶屏片选控制信号（低电平有效）                     |
 |     RS       --->      P12       //液晶屏命令/数据控制信号（低电平：命令，高电平：数据）|
 |     RST      --->      P33       //液晶屏复位控制信号（低电平有效）                     |
 |     SCL      --->      P17       //液晶屏SPI总线时钟信号                                |
 |     SDI      --->      P15       //液晶屏SPI总线写数据信号                              |
 |     SDO      --->      P16       //液晶屏SPI总线读数据信号                              |
 ===========================================================================================
 
 * 创建日期:2020/5/13
 * 版本：V1.0
 * 版权所有，盗版必究。
 * Copyright(C) 深圳市千一显示科技有限公司 2020-2035
 * All rights reserved
**********************************************************************/
#include <reg51.h>
#include <intrins.h>

#define	u8 unsigned char
#define	u16 unsigned int
#define	u32 unsigned long

//////////////////////////////////////////////////////////////////////////////////	  
//定义LCD的尺寸
#define LCD_W 240
#define LCD_H 320

#define SET_X_ADD_CMD 0x2A
#define SET_Y_ADD_CMD 0x2B
#define WR_RAM_CMD 0x2C

//IO连接
sbit LCD_RS = P1^2;  		 //数据/命令切换
sbit LCD_SDI = P1^5;		  //SPI写
sbit LCD_SDO = P1^6;		     //SPI读
sbit LCD_CS = P1^3;		//片选	
sbit LCD_CLK = P1^7;   //SPI时钟
sbit LCD_RESET = P3^3;	      //复位 
//sbit LCD_BL=P3^2;		//背光控制，如果不需要控制，接3.3V

//测试硬件平台：STC12C5A60S2/STC12LE5A60S2
//主频：12MHZ
//单片机IO推挽输出设置定义
#define MCU_STC12
#define		MAIN_Fosc	12000000L	//定义时钟
#ifdef MCU_STC12
//sfr P3M1  = 0xB1;	//P3M1.n,P3M0.n 	=00--->Standard,	01--->push-pull
//sfr P3M0  = 0xB2;	//					=10--->pure input,	11--->open drain
sfr AUXR1 = 0xA2;
#endif
//-----------------------------SPI 总线配置--------------------------------------//
//STC单片机硬件SPI寄存器定义
sfr SPSTAT = 0xCD;	//STC12C5A60S2系列
sfr SPCTL  = 0xCE;	//STC12C5A60S2系列
sfr SPDAT  = 0xCF;	//STC12C5A60S2系列
//sfr SPCTL   = 0x85;	SPI控制寄存器
//   7       6       5       4       3       2       1       0    	Reset Value
//	SSIG	SPEN	DORD	MSTR	CPOL	CPHA	SPR1	SPR0		0x00
#define	SSIG		1	//1: 忽略SS脚，由MSTR位决定主机还是从机		0: SS脚用于决定主从机。
#define	SPEN		1	//1: 允许SPI，								0：禁止SPI，所有SPI管脚均为普通IO
#define	DORD		0	//1：LSB先发，								0：MSB先发
#define	MSTR		1	//1：设为主机								0：设为从机
#define	CPOL		1	//1: 空闲时SCLK为高电平，					0：空闲时SCLK为低电平
#define	CPHA		1	//
#define	SPR1		0	//SPR1,SPR0   00: fosc/4,     01: fosc/16
#define	SPR0		0	//            10: fosc/64,    11: fosc/128
#define	SPEED_4		0	// fosc/4
#define	SPEED_16	1	// fosc/16
#define	SPEED_64	2	// fosc/64
#define	SPEED_128	3	// fosc/128

//sfr SPSTAT  = 0xCD;	//SPI状态寄存器
//   7       6      5   4   3   2   1   0    	Reset Value
//	SPIF	WCOL	-	-	-	-	-	-
#define	SPIF	0x80		//SPI传输完成标志。写入1清0。
#define	WCOL	0x40		//SPI写冲突标志。写入1清0。

//STC单片机IO推挽输出设置定义
//其他普通C51单片机无此配置请屏蔽下面这条语句

sfr P3M1  = 0xB1;	//P3M1.n,P3M0.n 	=00--->Standard,	01--->push-pull
sfr P3M0  = 0xB2;	//					=10--->pure input,	11--->open drain

//画笔颜色
#define WHITE         	 0xFFFF
#define BLACK         	 0x0000	  
#define BLUE         	 0x001F  
#define BRED             0XF81F
#define GRED 			 0XFFE0
#define GBLUE			 0X07FF
#define RED           	 0xF800
#define MAGENTA       	 0xF81F
#define GREEN         	 0x07E0
#define CYAN          	 0x7FFF
#define YELLOW        	 0xFFE0
#define BROWN 			 0XBC40 //棕色
#define BRRED 			 0XFC07 //棕红色
#define GRAY  			 0X8430 //灰色
#define GRAY0       0xEF7D 
#define GRAY1       0x8410      	//灰色1      00000 000000 00000
#define GRAY2       0x4208 
//GUI颜色

#define DARKBLUE      	 0X01CF	//深蓝色
#define LIGHTBLUE      	 0X7D7C	//浅蓝色  
#define GRAYBLUE       	 0X5458 //灰蓝色
//以上三色为PANEL的颜色 
 
#define LIGHTGREEN     	 0X841F //浅绿色
#define LGRAY 			 0XC618 //浅灰色(PANNEL),窗体背景色

#define LGRAYBLUE        0XA651 //浅灰蓝色(中间层颜色)
#define LBBLUE           0X2B12 //浅棕蓝色(选择条目的反色)
